@@ -1,8 +1,7 @@
-#!/usr/bin/env perl
 package Net::Jifty;
 use Any::Moose;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use LWP::UserAgent;
 use URI;
@@ -20,10 +19,10 @@ has site => (
     trigger       => sub {
         # this canonicalizes localhost to 127.0.0.1 because of an (I think)
         # HTTP::Cookies bug. cookies aren't sent out for localhost.
-        my ($self, $site, $attr) = @_;
+        my ($self, $site) = @_;
 
         if ($site =~ s/\blocalhost\b/127.0.0.1/) {
-            $attr->set_value($self, $site);
+            $self->site($site);
         }
     },
 );
@@ -974,10 +973,11 @@ Shawn M Moore, C<< <sartak at bestpractical.com> >>
 
 Ruslan Zakirov, C<< <ruz at bestpractical.com> >>
 
+Jesse Vincent, C<< <jesse at bestpractical.com> >>
+
 =head1 CONTRIBUTORS
 
 Andrew Sterling Hanenkamp, C<< <hanenkamp@gmail.com> >>,
-Ruslan Zakirov E<lt>ruz@bestpractical.comE<gt>
 
 =head1 BUGS
 
@@ -987,7 +987,7 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-Jifty>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007-2008 Best Practical Solutions.
+Copyright 2007-2009 Best Practical Solutions.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
